mono_connect library

The Mono Connect SDK is a quick and secure way to link bank accounts to Mono from within your Flutter app. Mono Connect is a drop-in framework that handles connecting a financial institution to your app (credential validation, multi-factor authentication, error handling, etc).

Classes

ConnectConfiguration
ConnectEvent
Represents an event dispatched by the Mono Connect Widget.
ConnectEventData
ConnectInstitution
ConnectWebView
This widget provides the interface for managing user account linking via Mono Connect.
MonoConnect
The Mono Connect SDK is a quick and secure way to link bank accounts to Mono from within your Flutter app. Mono Connect is a drop-in framework that handles connecting a financial institution to your app (credential validation, multi-factor authentication, error handling, etc).
MonoCustomer
MonoCustomerIdentity
MonoExistingCustomer
MonoNewCustomer

Enums

ConnectAuthMethod
ConnectEventType
Event types dispatched by the Mono Connect Widget.